@@ -1,7 +1,7 @@
 /*
  * Geekgame - a game which only real geeks understand
  * Copyright (C) 2002 - 2004 Josef Spillner, josef@ggzgamingzone.org
- * $Id: main.c 7271 2005-06-10 12:43:29Z josef $
+ * $Id: main.c 8856 2007-01-08 13:41:50Z josef $
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -61,8 +61,8 @@
 #include "config.h"
 
 /* Hard-coded definitions */
-#define SCREEN_WIDTH 800
-#define SCREEN_HEIGHT 600
+#define SCREEN_WIDTH_FALLBACK 800
+#define SCREEN_HEIGHT_FALLBACK 600
 
 #define ARRAY_WIDTH 20
 #define ARRAY_HEIGHT 10
@@ -91,6 +91,7 @@ static char array[ARRAY_WIDTH][ARRAY_HEIGHT];
 static int winner = -1;
 static int usesound = 1;
 static int usefullscreen = 0;
+static int useintro = 1;
 static int gamerunning = 0;
 static int modemenu = 0;
 static int arraywidth, arrayheight;
@@ -304,8 +305,8 @@ static void drawbox(int x, int y, int w, int h, SDL_Surface *screen,
 	}
 	else
 	{
-		if((x < 0) || (x + w > SCREEN_WIDTH - 5)) return;
-		if((y < 0) || (y + h > SCREEN_HEIGHT - 5)) return;
+		if((x < 0) || (x + w > screen->w - 5)) return;
+		if((y < 0) || (y + h > screen->h - 5)) return;
 	}
 
 	rect.x = x;
@@ -388,12 +389,13 @@ int main(int argc, char *argv[])
 		{"help", no_argument, 0, 'h'},
 		{"nosound", no_argument, 0, 'n'},
 		{"players", required_argument, 0, 'p'},
+		{"skipintro", no_argument, 0, 's'},
 		{0, 0, 0, 0}
 	};
 	int index = 0, c;
 	int ret;
 
-	while((c = getopt_long(argc, argv, "fghnp:", op, &index)) != -1)
+	while((c = getopt_long(argc, argv, "fghnp:s", op, &index)) != -1)
 	{
 		switch(c)
 		{
@@ -411,6 +413,7 @@ int main(int argc, char *argv[])
 				printf("[-g | --ggz       ] Run game in GGZ mode\n");
 				printf("[-h | --help      ] This help\n");
 				printf("[-n | --nosound   ] Don't use sound or music\n");
+				printf("[-s | --skipintro ] Skip the introductory animation\n");
 				printf("[-p | --players=x ] Number of players for single player mode ");
 				printf("(default: %i)\n", MAX_PLAYERS);
 				return 0;
@@ -426,6 +429,9 @@ int main(int argc, char *argv[])
 					players = MAX_PLAYERS;
 				}
 				break;
+			case 's':
+				useintro = 0;
+				break;
 			default:
 				fprintf(stderr, "Type '%s --help' to get a list of options.\n", argv[0]);
 				return 1;
@@ -530,8 +536,9 @@ void rendermode(int x, int y, const char *mode)
 	SDL_Rect rect;
 
 	SDL_Color green = {0x3F, 0xFF, 0x5F, 0};
+	SDL_Color black = {0x00, 0x00, 0x00, 0};
 
-	text = TTF_RenderText_Solid(font, mode, green);
+	text = TTF_RenderUTF8_Shaded(font, mode, green, black);
 	if(text)
 	{
 		rect.x = x;
@@ -552,10 +559,11 @@ static void renderscore(int x, int y, int sum)
 	SDL_Surface *text;
 	SDL_Rect rect;
 
-	SDL_Color black = {0xFF, 0xFF, 0xFF, 0};
+	SDL_Color white = {0xFF, 0xFF, 0xFF, 0};
+	SDL_Color black = {0x00, 0x00, 0x00, 0};
 
 	snprintf(score, sizeof(score), "%i", sum);
-	text = TTF_RenderText_Solid(font, score, black);
+	text = TTF_RenderUTF8_Shaded(font, score, white, black);
 	if(text)
 	{
 		rect.x = x;
@@ -586,7 +594,7 @@ static void renderdesc(int x, int y, const char *desc, int active)
 	token = strtok(tmp, "\n");
 	while(token)
 	{
-		text = TTF_RenderText_Solid(font, token, (active ? white : black));
+		text = TTF_RenderUTF8_Shaded(font, token, (active ? white : black), black);
 		if(text)
 		{
 			rect.x = x;
@@ -668,8 +676,8 @@ static void screen_scanning(int display)
 	{
 		rect.x = 0;
 		rect.y = 0;
-		rect.w = SCREEN_WIDTH;
-		rect.h = SCREEN_HEIGHT;
+		rect.w = screen->w;
+		rect.h = screen->h;
 		SDL_FillRect(screen, &rect, SDL_MapRGB(screen->format, 0, 0, 0));
 
 		renderdesc(50, 50, "Scanning...", 1);
@@ -701,8 +709,11 @@ static void screen_scanning(int display)
 			snprintf(path, sizeof(path), "%s/fonts", data_global());
 			fontpath = scan_file(path, "*.ttf");
 		}
-		if(!fontpath) fontpath = scan_file("/usr/share/fonts/truetype", "*.ttf");
+		if(!fontpath) fontpath = scan_file("/usr/share/fonts/truetype/ttf-bitstream-vera", "Vera.ttf");
+		if(!fontpath) fontpath = scan_file("/usr/share/fonts/truetype/ttf-bitstream-vera", "*.ttf");
 		if(!fontpath) fontpath = scan_file("/usr/share/fonts/truetype/freefont", "*.ttf");
+		if(!fontpath) fontpath = scan_file("/usr/share/fonts/truetype/openoffice", "*.ttf");
+		if(!fontpath) fontpath = scan_file("/usr/share/fonts/truetype", "*.ttf");
 		if(!fontpath) fontpath = scan_file("/usr/X11R6/lib/X11/fonts/TrueType", "*.ttf");
 
 		/* Scanning for music */
@@ -790,8 +801,8 @@ static void screen_intro(int firsttime)
 
 	rect.x = 0;
 	rect.y = 0;
-	rect.w = SCREEN_WIDTH;
-	rect.h = SCREEN_HEIGHT;
+	rect.w = screen->w;
+	rect.h = screen->h;
 	SDL_FillRect(screen, &rect, SDL_MapRGB(screen->format, 0, 0, 0));
 	SDL_UpdateRect(screen, rect.x, rect.y, rect.w, rect.h);
 
@@ -1361,8 +1372,8 @@ static void screen_outtro(void)
 
 	rect.x = 0;
 	rect.y = 0;
-	rect.w = SCREEN_WIDTH;
-	rect.h = SCREEN_HEIGHT;
+	rect.w = screen->w;
+	rect.h = screen->h;
 	SDL_FillRect(screen, &rect, SDL_MapRGB(screen->format, 0, 0, 0));
 	rendermode(22, 24, "The game is over.");
 	if(!ggzmode)
@@ -1398,6 +1409,8 @@ int startgame(void)
 	Uint32 init;
 	char path[STRING_LENGTH];
 	int step;
+	int scrwidth, scrheight;
+	const SDL_VideoInfo *vidinfo;
 
 	init = SDL_INIT_VIDEO;
 #ifdef HAVE_SOUND
@@ -1451,12 +1464,27 @@ int startgame(void)
 	icon = IMG_Load(path);
 	if(icon) SDL_WM_SetIcon(icon, 0);
 
-	screen = SDL_SetVideoMode(SCREEN_WIDTH, SCREEN_HEIGHT, 0,
-		SDL_OPENGL | (usefullscreen ? SDL_FULLSCREEN : SDL_RESIZABLE));
+	if(usefullscreen)
+	{
+		vidinfo = SDL_GetVideoInfo();
+		scrwidth = vidinfo->current_w;
+		scrheight = vidinfo->current_h;
+	}
+	else
+	{
+		scrwidth = SCREEN_WIDTH_FALLBACK;
+		scrheight = SCREEN_HEIGHT_FALLBACK;
+	}
 
-	geekgame_intro();
+	if(useintro)
+	{
+		screen = SDL_SetVideoMode(scrwidth, scrheight, 0,
+			SDL_OPENGL | (usefullscreen ? SDL_FULLSCREEN : SDL_RESIZABLE));
 
-	screen = SDL_SetVideoMode(SCREEN_WIDTH, SCREEN_HEIGHT, 0,
+		geekgame_intro();
+	}
+
+	screen = SDL_SetVideoMode(scrwidth, scrheight, 0,
 		(usefullscreen ? SDL_FULLSCREEN : 0));
 
 	if(!players) players = MAX_PLAYERS;
